@@ -106,6 +106,8 @@ public:
     void TangensHyp(const KNumber &input);
 
     void Reset();
+    void setOnlyUpdateOperation(bool update);
+    bool getOnlyUpdateOperation() const;
 
 private:
     KStats stats;
@@ -138,6 +140,11 @@ private:
 
     KNumber last_number_;
 
+    Operation last_operation_;
+    KNumber last_repeat_number_;
+    bool repeat_mode_;
+    bool only_update_operation_;
+
     bool percent_mode_;
 
     bool evalStack();
