@@ -28,13 +28,13 @@ namespace detail {
 
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::knumber_error(Error e) : error_(e) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::knumber_error(const QString &s) {
 
@@ -45,45 +45,45 @@ knumber_error::knumber_error(const QString &s) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::knumber_error() : error_(ERROR_UNDEFINED) {
 
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::~knumber_error() {
 
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::knumber_error(const knumber_integer *) : error_(ERROR_UNDEFINED) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::knumber_error(const knumber_fraction *) : error_(ERROR_UNDEFINED) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::knumber_error(const knumber_float *) : error_(ERROR_UNDEFINED) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_error::knumber_error(const knumber_error *value) : error_(value->error_) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 QString knumber_error::toString(int precision) const {
 
@@ -91,17 +91,17 @@ QString knumber_error::toString(int precision) const {
 
 	switch(error_) {
 	case ERROR_POS_INFINITY:
-		return QLatin1String("inf");
+		return QStringLiteral("inf");
 	case ERROR_NEG_INFINITY:
-		return QLatin1String("-inf");
+		return QStringLiteral("-inf");
 	case ERROR_UNDEFINED:
 	default:
-		return QLatin1String("nan");
+		return QStringLiteral("nan");
 	}
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::add(knumber_base *rhs) {
 
@@ -124,13 +124,13 @@ knumber_base *knumber_error::add(knumber_base *rhs) {
 		}
 		return this;
 	}
-	
+
 	Q_ASSERT(0);
-	return 0;
+	return nullptr;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::sub(knumber_base *rhs) {
 
@@ -153,13 +153,13 @@ knumber_base *knumber_error::sub(knumber_base *rhs) {
 		}
 		return this;
 	}
-	
+
 	Q_ASSERT(0);
-	return 0;
+	return nullptr;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::mul(knumber_base *rhs) {
 
@@ -190,13 +190,13 @@ knumber_base *knumber_error::mul(knumber_base *rhs) {
 		}
 		return this;
 	}
-	
+
 	Q_ASSERT(0);
-	return 0;
+	return nullptr;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::div(knumber_base *rhs) {
 
@@ -214,13 +214,13 @@ knumber_base *knumber_error::div(knumber_base *rhs) {
 		error_ = ERROR_UNDEFINED;
 		return this;
 	}
-	
+
 	Q_ASSERT(0);
-	return 0;
+	return nullptr;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::mod(knumber_base *rhs) {
 
@@ -238,13 +238,13 @@ knumber_base *knumber_error::mod(knumber_base *rhs) {
 		error_ = ERROR_UNDEFINED;
 		return this;
 	}
-	
+
 	Q_ASSERT(0);
-	return 0;
+	return nullptr;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::pow(knumber_base *rhs) {
 
@@ -258,7 +258,7 @@ knumber_base *knumber_error::pow(knumber_base *rhs) {
 		Q_UNUSED(p);
 		return this;
 	} else if(knumber_error *const p = dynamic_cast<knumber_error *>(rhs)) {
-		
+
 		switch(error_) {
 		case ERROR_POS_INFINITY:
 			if(p->sign() > 0) {
@@ -289,13 +289,13 @@ knumber_base *knumber_error::pow(knumber_base *rhs) {
 			return this;
 		}
 	}
-	
+
 	Q_ASSERT(0);
-	return 0;
+	return nullptr;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::neg() {
 
@@ -310,12 +310,12 @@ knumber_base *knumber_error::neg() {
 	default:
 		break;
 	}
-	
+
 	return this;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::cmp() {
 
@@ -324,7 +324,7 @@ knumber_base *knumber_error::cmp() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::abs() {
 
@@ -337,12 +337,12 @@ knumber_base *knumber_error::abs() {
 	default:
 		break;
 	}
-	
+
 	return this;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::sqrt() {
 
@@ -355,12 +355,12 @@ knumber_base *knumber_error::sqrt() {
 	default:
 		break;
 	}
-	
+
 	return this;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::cbrt() {
 
@@ -368,7 +368,7 @@ knumber_base *knumber_error::cbrt() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::factorial() {
 	error_ = ERROR_UNDEFINED;
@@ -376,7 +376,7 @@ knumber_base *knumber_error::factorial() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::sin() {
 
@@ -385,7 +385,7 @@ knumber_base *knumber_error::sin() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::cos() {
 
@@ -394,7 +394,16 @@ knumber_base *knumber_error::cos() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
+//------------------------------------------------------------------------------
+knumber_base* knumber_error::tgamma() {
+
+	error_ = ERROR_UNDEFINED;
+	return this;
+}
+
+//------------------------------------------------------------------------------
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::tan() {
 
@@ -403,7 +412,7 @@ knumber_base *knumber_error::tan() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::asin() {
 
@@ -412,7 +421,7 @@ knumber_base *knumber_error::asin() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::acos() {
 
@@ -421,10 +430,10 @@ knumber_base *knumber_error::acos() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::atan() {
-	
+
 	switch(error_) {
     case ERROR_POS_INFINITY:
 		delete this;
@@ -439,7 +448,7 @@ knumber_base *knumber_error::atan() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::sinh() {
 
@@ -447,7 +456,7 @@ knumber_base *knumber_error::sinh() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::cosh() {
 
@@ -456,7 +465,7 @@ knumber_base *knumber_error::cosh() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::tanh() {
 
@@ -472,7 +481,7 @@ knumber_base *knumber_error::tanh() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::asinh() {
 
@@ -480,19 +489,19 @@ knumber_base *knumber_error::asinh() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::acosh() {
-	
+
 	if(sign() < 0) {
 		error_ = ERROR_UNDEFINED;
 	}
-	
+
 	return this;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::atanh() {
 
@@ -501,7 +510,7 @@ knumber_base *knumber_error::atanh() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 int knumber_error::compare(knumber_base *rhs) {
 
@@ -526,20 +535,20 @@ int knumber_error::compare(knumber_base *rhs) {
 	} else if(knumber_error *const p = dynamic_cast<knumber_error *>(rhs)) {
 		return sign() == p->sign();
 	}
-	
+
 	Q_ASSERT(0);
 	return 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::clone() {
 	return new knumber_error(this);
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::bitwise_and(knumber_base *rhs) {
 	Q_UNUSED(rhs);
@@ -548,7 +557,7 @@ knumber_base *knumber_error::bitwise_and(knumber_base *rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::bitwise_xor(knumber_base *rhs) {
 	Q_UNUSED(rhs);
@@ -557,7 +566,7 @@ knumber_base *knumber_error::bitwise_xor(knumber_base *rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::bitwise_or(knumber_base *rhs) {
 	Q_UNUSED(rhs);
@@ -566,7 +575,7 @@ knumber_base *knumber_error::bitwise_or(knumber_base *rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::bitwise_shift(knumber_base *rhs) {
 	Q_UNUSED(rhs);
@@ -575,7 +584,7 @@ knumber_base *knumber_error::bitwise_shift(knumber_base *rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool knumber_error::is_integer() const {
 
@@ -583,7 +592,7 @@ bool knumber_error::is_integer() const {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool knumber_error::is_zero() const {
 
@@ -591,7 +600,7 @@ bool knumber_error::is_zero() const {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 int knumber_error::sign() const {
 
@@ -607,7 +616,7 @@ int knumber_error::sign() const {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::reciprocal() {
 
@@ -616,7 +625,7 @@ knumber_base *knumber_error::reciprocal() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::log2() {
 	error_ = ERROR_UNDEFINED;
@@ -624,7 +633,7 @@ knumber_base *knumber_error::log2() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::log10() {
 	error_ = ERROR_UNDEFINED;
@@ -632,7 +641,7 @@ knumber_base *knumber_error::log10() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::ln() {
 	error_ = ERROR_UNDEFINED;
@@ -640,7 +649,23 @@ knumber_base *knumber_error::ln() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
+//------------------------------------------------------------------------------
+knumber_base *knumber_error::ceil() {
+	error_ = ERROR_UNDEFINED;
+	return this;
+}
+
+//------------------------------------------------------------------------------
+// Name:
+//------------------------------------------------------------------------------
+knumber_base *knumber_error::floor() {
+	error_ = ERROR_UNDEFINED;
+	return this;
+}
+
+//------------------------------------------------------------------------------
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::exp2() {
 	error_ = ERROR_UNDEFINED;
@@ -648,7 +673,7 @@ knumber_base *knumber_error::exp2() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::exp10() {
 	error_ = ERROR_UNDEFINED;
@@ -656,7 +681,7 @@ knumber_base *knumber_error::exp10() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::exp() {
 	error_ = ERROR_UNDEFINED;
@@ -664,21 +689,21 @@ knumber_base *knumber_error::exp() {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 quint64 knumber_error::toUint64() const {
 	return 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 qint64 knumber_error::toInt64() const {
 	return 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 knumber_base *knumber_error::bin(knumber_base *rhs) {
 	Q_UNUSED(rhs);
